@@ -4,11 +4,7 @@
 <!--BEGIN STABILITY BANNER-->---
 
 
-![Stability: Experimental](https://img.shields.io/badge/stability-Experimental-important.svg?style=for-the-badge)
-
-> All classes are under active development and subject to non-backward compatible changes or removal in any
-> future version. These are not subject to the [Semantic Versioning](https://semver.org/) model.
-> This means that while you may use them, you may need to update your source code when upgrading to a newer version of this package.
+![Stability: Stable](https://img.shields.io/badge/cfn--resources-stable-success.svg?style=for-the-badge)
 
 ---
 <!--END STABILITY BANNER-->
@@ -61,6 +57,7 @@ new ApiGatewayToKinesisStreams(scope: Construct, id: string, props: ApiGatewayTo
 |existingStreamObj?|[`kinesis.Stream`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.Stream.html)|Existing instance of Kinesis Stream, providing both this and `kinesisStreamProps` will cause an error.|
 |kinesisStreamProps?|[`kinesis.StreamProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.StreamProps.html)|Optional user-provided props to override the default props for the Kinesis stream.|
 |logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroupProps.html)|User provided props to override the default props for for the CloudWatchLogs LogGroup.|
+|createCloudWatchAlarms|`boolean`|Whether to create recommended CloudWatch alarms for Kinesis Data Stream. Default value is set to `true`|
 
 ## Pattern Properties
 
@@ -68,9 +65,10 @@ new ApiGatewayToKinesisStreams(scope: Construct, id: string, props: ApiGatewayTo
 |:-------------|:----------------|-----------------|
 |apiGateway|[`api.RestApi`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-apigateway.RestApi.html)|Returns an instance of the API Gateway REST API created by the pattern.|
 |apiGatewayRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for API Gateway.|
-|apiGatewayCloudWatchRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for API Gateway for CloudWatch access.|
+|apiGatewayCloudWatchRole?|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for API Gateway for CloudWatch access.|
 |apiGatewayLogGroup|[`logs.LogGroup`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroup.html)|Returns an instance of the LogGroup created by the construct for API Gateway access logging to CloudWatch.|
 |kinesisStream|[`kinesis.Stream`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.Stream.html)|Returns an instance of the Kinesis stream created or used by the pattern.|
+|cloudwatchAlarms?|[`cloudwatch.Alarm[]`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudwatch.Alarm.html)|Returns an array of recommended CloudWatch Alarms created by the construct for Kinesis Data stream|
 
 ## Sample API Usage
 
@@ -119,6 +117,7 @@ import typing_extensions
 from ._jsii import *
 
 import aws_cdk.aws_apigateway
+import aws_cdk.aws_cloudwatch
 import aws_cdk.aws_iam
 import aws_cdk.aws_kinesis
 import aws_cdk.aws_logs
@@ -140,6 +139,7 @@ class ApiGatewayToKinesisStreams(
         id: builtins.str,
         *,
         api_gateway_props: typing.Optional[aws_cdk.aws_apigateway.RestApiProps] = None,
+        create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
         log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
@@ -152,6 +152,7 @@ class ApiGatewayToKinesisStreams(
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param api_gateway_props: Optional user-provided props to override the default props for the API Gateway. Default: - Default properties are used.
+        :param create_cloud_watch_alarms: Whether to create recommended CloudWatch alarms. Default: - Alarms are created
         :param existing_stream_obj: Existing instance of Kinesis Stream, providing both this and ``kinesisStreamProps`` will cause an error. Default: - None
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis Data Stream. Default: - Default properties are used.
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
@@ -166,6 +167,7 @@ class ApiGatewayToKinesisStreams(
         '''
         props = ApiGatewayToKinesisStreamsProps(
             api_gateway_props=api_gateway_props,
+            create_cloud_watch_alarms=create_cloud_watch_alarms,
             existing_stream_obj=existing_stream_obj,
             kinesis_stream_props=kinesis_stream_props,
             log_group_props=log_group_props,
@@ -182,11 +184,6 @@ class ApiGatewayToKinesisStreams(
     def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
         return typing.cast(aws_cdk.aws_apigateway.RestApi, jsii.get(self, "apiGateway"))
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="apiGatewayCloudWatchRole")
-    def api_gateway_cloud_watch_role(self) -> aws_cdk.aws_iam.Role:
-        return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "apiGatewayCloudWatchRole"))
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="apiGatewayLogGroup")
     def api_gateway_log_group(self) -> aws_cdk.aws_logs.LogGroup:
@@ -202,12 +199,25 @@ class ApiGatewayToKinesisStreams(
     def kinesis_stream(self) -> aws_cdk.aws_kinesis.Stream:
         return typing.cast(aws_cdk.aws_kinesis.Stream, jsii.get(self, "kinesisStream"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="apiGatewayCloudWatchRole")
+    def api_gateway_cloud_watch_role(self) -> typing.Optional[aws_cdk.aws_iam.Role]:
+        return typing.cast(typing.Optional[aws_cdk.aws_iam.Role], jsii.get(self, "apiGatewayCloudWatchRole"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="cloudwatchAlarms")
+    def cloudwatch_alarms(
+        self,
+    ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
+        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
+
 
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/aws-apigateway-kinesisstreams.ApiGatewayToKinesisStreamsProps",
     jsii_struct_bases=[],
     name_mapping={
         "api_gateway_props": "apiGatewayProps",
+        "create_cloud_watch_alarms": "createCloudWatchAlarms",
         "existing_stream_obj": "existingStreamObj",
         "kinesis_stream_props": "kinesisStreamProps",
         "log_group_props": "logGroupProps",
@@ -222,6 +232,7 @@ class ApiGatewayToKinesisStreamsProps:
         self,
         *,
         api_gateway_props: typing.Optional[aws_cdk.aws_apigateway.RestApiProps] = None,
+        create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
         log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
@@ -232,6 +243,7 @@ class ApiGatewayToKinesisStreamsProps:
     ) -> None:
         '''
         :param api_gateway_props: Optional user-provided props to override the default props for the API Gateway. Default: - Default properties are used.
+        :param create_cloud_watch_alarms: Whether to create recommended CloudWatch alarms. Default: - Alarms are created
         :param existing_stream_obj: Existing instance of Kinesis Stream, providing both this and ``kinesisStreamProps`` will cause an error. Default: - None
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis Data Stream. Default: - Default properties are used.
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
@@ -255,6 +267,8 @@ class ApiGatewayToKinesisStreamsProps:
         self._values: typing.Dict[str, typing.Any] = {}
         if api_gateway_props is not None:
             self._values["api_gateway_props"] = api_gateway_props
+        if create_cloud_watch_alarms is not None:
+            self._values["create_cloud_watch_alarms"] = create_cloud_watch_alarms
         if existing_stream_obj is not None:
             self._values["existing_stream_obj"] = existing_stream_obj
         if kinesis_stream_props is not None:
@@ -279,6 +293,15 @@ class ApiGatewayToKinesisStreamsProps:
         result = self._values.get("api_gateway_props")
         return typing.cast(typing.Optional[aws_cdk.aws_apigateway.RestApiProps], result)
 
+    @builtins.property
+    def create_cloud_watch_alarms(self) -> typing.Optional[builtins.bool]:
+        '''Whether to create recommended CloudWatch alarms.
+
+        :default: - Alarms are created
+        '''
+        result = self._values.get("create_cloud_watch_alarms")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def existing_stream_obj(self) -> typing.Optional[aws_cdk.aws_kinesis.Stream]:
         '''Existing instance of Kinesis Stream, providing both this and ``kinesisStreamProps`` will cause an error.
